Struct google_compute1::api::Address[][src]

pub struct Address {
    pub address: Option<String>,
    pub address_type: Option<String>,
    pub creation_timestamp: Option<String>,
    pub description: Option<String>,
    pub id: Option<String>,
    pub ip_version: Option<String>,
    pub kind: Option<String>,
    pub name: Option<String>,
    pub network: Option<String>,
    pub network_tier: Option<String>,
    pub prefix_length: Option<i32>,
    pub purpose: Option<String>,
    pub region: Option<String>,
    pub self_link: Option<String>,
    pub status: Option<String>,
    pub subnetwork: Option<String>,
    pub users: Option<Vec<String>>,
}

Use global external addresses for GFE-based external HTTP(S) load balancers in Premium Tier.

Use global internal addresses for reserved peering network range.

Use regional external addresses for the following resources:

  • External IP addresses for VM instances - Regional external forwarding rules - Cloud NAT external IP addresses - GFE based LBs in Standard Tier - Network LBs in Premium or Standard Tier - Cloud VPN gateways (both Classic and HA)

Use regional internal IP addresses for subnet IP ranges (primary and secondary). This includes:

  • Internal IP addresses for VM instances - Alias IP ranges of VM instances (/32 only) - Regional internal forwarding rules - Internal TCP/UDP load balancer addresses - Internal HTTP(S) load balancer addresses - Cloud DNS inbound forwarding IP addresses

For more information, read reserved IP address.

(== resource_for {$api_version}.addresses ==) (== resource_for {$api_version}.globalAddresses ==)

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

address: Option<String>

The static IP address represented by this resource.

address_type: Option<String>

The type of address to reserve, either INTERNAL or EXTERNAL. If unspecified, defaults to EXTERNAL.

creation_timestamp: Option<String>

[Output Only] Creation timestamp in RFC3339 text format.

description: Option<String>

An optional description of this resource. Provide this field when you create the resource.

id: Option<String>

[Output Only] The unique identifier for the resource. This identifier is defined by the server.

ip_version: Option<String>

The IP version that will be used by this address. Valid options are IPV4 or IPV6. This can only be specified for a global address.

kind: Option<String>

[Output Only] Type of the resource. Always compute#address for addresses.

name: Option<String>

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.

network: Option<String>

The URL of the network in which to reserve the address. This field can only be used with INTERNAL type with the VPC_PEERING purpose.

network_tier: Option<String>

This signifies the networking tier used for configuring this address and can only take the following values: PREMIUM or STANDARD. Global forwarding rules can only be Premium Tier. Regional forwarding rules can be either Premium or Standard Tier. Standard Tier addresses applied to regional forwarding rules can be used with any external load balancer. Regional forwarding rules in Premium Tier can only be used with a network load balancer.

If this field is not specified, it is assumed to be PREMIUM.

prefix_length: Option<i32>

The prefix length if the resource represents an IP range.

purpose: Option<String>

The purpose of this resource, which can be one of the following values:

  • GCE_ENDPOINT for addresses that are used by VM instances, alias IP ranges, internal load balancers, and similar resources.
  • DNS_RESOLVER for a DNS resolver address in a subnetwork
  • VPC_PEERING for addresses that are reserved for VPC peer networks.
  • NAT_AUTO for addresses that are external IP addresses automatically reserved for Cloud NAT.
  • IPSEC_INTERCONNECT for addresses created from a private IP range that are reserved for a VLAN attachment in an IPsec-encrypted Cloud Interconnect configuration. These addresses are regional resources.
region: Option<String>

[Output Only] The URL of the region where a regional address resides. For regional addresses, you must specify the region as a path parameter in the HTTP request URL. This field is not applicable to global addresses.

self_link: Option<String>

[Output Only] Server-defined URL for the resource.

status: Option<String>

[Output Only] The status of the address, which can be one of RESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently in the process of being reserved. A RESERVED address is currently reserved and available to use. An IN_USE address is currently being used by another resource and is not available.

subnetwork: Option<String>

The URL of the subnetwork in which to reserve the address. If an IP address is specified, it must be within the subnetwork’s IP range. This field can only be used with INTERNAL type with a GCE_ENDPOINT or DNS_RESOLVER purpose.

users: Option<Vec<String>>

[Output Only] The URLs of the resources that are using this address.