Struct google_compute1::api::Autoscaler[][src]

pub struct Autoscaler {
    pub autoscaling_policy: Option<AutoscalingPolicy>,
    pub creation_timestamp: Option<String>,
    pub description: Option<String>,
    pub id: Option<String>,
    pub kind: Option<String>,
    pub name: Option<String>,
    pub recommended_size: Option<i32>,
    pub region: Option<String>,
    pub scaling_schedule_status: Option<HashMap<String, ScalingScheduleStatus>>,
    pub self_link: Option<String>,
    pub status: Option<String>,
    pub status_details: Option<Vec<AutoscalerStatusDetails>>,
    pub target: Option<String>,
    pub zone: Option<String>,
}

Represents an Autoscaler resource.

Google Compute Engine has two Autoscaler resources:

Use autoscalers to automatically add or delete instances from a managed instance group according to your defined autoscaling policy. For more information, read Autoscaling Groups of Instances.

For zonal managed instance groups resource, use the autoscaler resource.

For regional managed instance groups, use the regionAutoscalers resource. (== resource_for {$api_version}.autoscalers ==) (== resource_for {$api_version}.regionAutoscalers ==)

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

autoscaling_policy: Option<AutoscalingPolicy>

The configuration parameters for the autoscaling algorithm. You can define one or more of the policies for an autoscaler: cpuUtilization, customMetricUtilizations, and loadBalancingUtilization.

If none of these are specified, the default will be to autoscale based on cpuUtilization to 0.6 or 60%.

creation_timestamp: Option<String>

[Output Only] Creation timestamp in RFC3339 text format.

description: Option<String>

An optional description of this resource. Provide this property when you create the resource.

id: Option<String>

[Output Only] The unique identifier for the resource. This identifier is defined by the server.

kind: Option<String>

[Output Only] Type of the resource. Always compute#autoscaler for autoscalers.

name: Option<String>

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

recommended_size: Option<i32>

[Output Only] Target recommended MIG size (number of instances) computed by autoscaler. Autoscaler calculates the recommended MIG size even when the autoscaling policy mode is different from ON. This field is empty when autoscaler is not connected to an existing managed instance group or autoscaler did not generate its prediction.

region: Option<String>

[Output Only] URL of the region where the instance group resides (for autoscalers living in regional scope).

scaling_schedule_status: Option<HashMap<String, ScalingScheduleStatus>>

[Output Only] Status information of existing scaling schedules.

self_link: Option<String>

[Output Only] Server-defined URL for the resource.

status: Option<String>

[Output Only] The status of the autoscaler configuration. Current set of possible values:

  • PENDING: Autoscaler backend hasn’t read new/updated configuration.
  • DELETING: Configuration is being deleted.
  • ACTIVE: Configuration is acknowledged to be effective. Some warnings might be present in the statusDetails field.
  • ERROR: Configuration has errors. Actionable for users. Details are present in the statusDetails field. New values might be added in the future.
status_details: Option<Vec<AutoscalerStatusDetails>>

[Output Only] Human-readable details about the current state of the autoscaler. Read the documentation for Commonly returned status messages for examples of status messages you might encounter.

target: Option<String>

URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler.

zone: Option<String>

[Output Only] URL of the zone where the instance group resides (for autoscalers living in zonal scope).