pub struct AutoscalersScopedListWarningData {
pub key: Option<String>,
pub value: Option<String>,
}Expand description
[Output Only] Metadata about this warning in key: value format. For example: “data”: [ { “key”: “scope”, “value”: “zones/us-east1-d” }
This type is not used in any activity, and only used as part of another schema.
Fields
key: Option<String>[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding).
value: Option<String>[Output Only] A warning data value corresponding to the key.