Struct google_compute1::api::AutoscalingPolicy[][src]

pub struct AutoscalingPolicy {
    pub cool_down_period_sec: Option<i32>,
    pub cpu_utilization: Option<AutoscalingPolicyCpuUtilization>,
    pub custom_metric_utilizations: Option<Vec<AutoscalingPolicyCustomMetricUtilization>>,
    pub load_balancing_utilization: Option<AutoscalingPolicyLoadBalancingUtilization>,
    pub max_num_replicas: Option<i32>,
    pub min_num_replicas: Option<i32>,
    pub mode: Option<String>,
    pub scale_in_control: Option<AutoscalingPolicyScaleInControl>,
    pub scaling_schedules: Option<HashMap<String, AutoscalingPolicyScalingSchedule>>,
}

Cloud Autoscaler policy.

This type is not used in any activity, and only used as part of another schema.

Fields

cool_down_period_sec: Option<i32>

The number of seconds that the autoscaler waits before it starts collecting information from a new instance. This prevents the autoscaler from collecting information when the instance is initializing, during which the collected usage would not be reliable. The default time autoscaler waits is 60 seconds.

Virtual machine initialization times might vary because of numerous factors. We recommend that you test how long an instance may take to initialize. To do this, create an instance and time the startup process.

cpu_utilization: Option<AutoscalingPolicyCpuUtilization>

Defines the CPU utilization policy that allows the autoscaler to scale based on the average CPU utilization of a managed instance group.

custom_metric_utilizations: Option<Vec<AutoscalingPolicyCustomMetricUtilization>>

Configuration parameters of autoscaling based on a custom metric.

load_balancing_utilization: Option<AutoscalingPolicyLoadBalancingUtilization>

Configuration parameters of autoscaling based on load balancer.

max_num_replicas: Option<i32>

The maximum number of instances that the autoscaler can scale out to. This is required when creating or updating an autoscaler. The maximum number of replicas must not be lower than minimal number of replicas.

min_num_replicas: Option<i32>

The minimum number of replicas that the autoscaler can scale in to. This cannot be less than 0. If not provided, autoscaler chooses a default value depending on maximum number of instances allowed.

mode: Option<String>

Defines operating mode for this policy.

scale_in_control: Option<AutoscalingPolicyScaleInControl>

no description provided

scaling_schedules: Option<HashMap<String, AutoscalingPolicyScalingSchedule>>

Scaling schedules defined for an autoscaler. Multiple schedules can be set on an autoscaler, and they can overlap. During overlapping periods the greatest min_required_replicas of all scaling schedules is applied. Up to 128 scaling schedules are allowed.