Struct google_compute1::api::DisksResizeRequest[][src]

pub struct DisksResizeRequest {
    pub size_gb: Option<String>,
}

There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

size_gb: Option<String>

The new size of the persistent disk, which is specified in GB.