pub struct DisksScopedList {
pub disks: Option<Vec<Disk>>,
pub warning: Option<DisksScopedListWarning>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
disks: Option<Vec<Disk>>[Output Only] A list of disks contained in this scope.
warning: Option<DisksScopedListWarning>[Output Only] Informational warning which replaces the list of disks when the list is empty.