Struct google_compute1::api::Duration[][src]

pub struct Duration {
    pub nanos: Option<i32>,
    pub seconds: Option<String>,
}

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like “day” or “month”. Range is approximately 10,000 years.

This type is not used in any activity, and only used as part of another schema.

Fields

nanos: Option<i32>

Span of time that’s a fraction of a second at nanosecond resolution. Durations less than one second are represented with a 0 seconds field and a positive nanos field. Must be from 0 to 999,999,999 inclusive.

seconds: Option<String>

Span of time at a resolution of a second. Must be from 0 to 315,576,000,000 inclusive. Note: these bounds are computed from: 60 sec/min * 60 min/hr * 24 hr/day * 365.25 days/year * 10000 years