pub struct InstancesScopedList {
pub instances: Option<Vec<Instance>>,
pub warning: Option<InstancesScopedListWarning>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
instances: Option<Vec<Instance>>[Output Only] A list of instances contained in this scope.
warning: Option<InstancesScopedListWarning>[Output Only] Informational warning which replaces the list of instances when the list is empty.