Struct google_compute1::api::InterconnectDiagnosticsLinkOpticalPower [−][src]
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
state: Option<String>The status of the current value when compared to the warning and alarm levels for the receiving or transmitting transceiver. Possible states include:
- OK: The value has not crossed a warning threshold.
- LOW_WARNING: The value has crossed below the low warning threshold.
- HIGH_WARNING: The value has crossed above the high warning threshold.
- LOW_ALARM: The value has crossed below the low alarm threshold.
- HIGH_ALARM: The value has crossed above the high alarm threshold.
value: Option<f32>Value of the current receiving or transmitting optical power, read in dBm. Take a known good optical value, give it a 10% margin and trigger warnings relative to that value. In general, a -7dBm warning and a -11dBm alarm are good optical value estimates for most links.