Struct google_compute1::api::InterconnectDiagnosticsLinkStatus[][src]

pub struct InterconnectDiagnosticsLinkStatus {
    pub arp_caches: Option<Vec<InterconnectDiagnosticsARPEntry>>,
    pub circuit_id: Option<String>,
    pub google_demarc: Option<String>,
    pub lacp_status: Option<InterconnectDiagnosticsLinkLACPStatus>,
    pub receiving_optical_power: Option<InterconnectDiagnosticsLinkOpticalPower>,
    pub transmitting_optical_power: Option<InterconnectDiagnosticsLinkOpticalPower>,
}

There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

arp_caches: Option<Vec<InterconnectDiagnosticsARPEntry>>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled

circuit_id: Option<String>

The unique ID for this link assigned during turn up by Google.

google_demarc: Option<String>

The Demarc address assigned by Google and provided in the LoA.

lacp_status: Option<InterconnectDiagnosticsLinkLACPStatus>

no description provided

receiving_optical_power: Option<InterconnectDiagnosticsLinkOpticalPower>

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.

transmitting_optical_power: Option<InterconnectDiagnosticsLinkOpticalPower>

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.