Struct google_compute1::api::InterconnectLocation[][src]

pub struct InterconnectLocation {
    pub address: Option<String>,
    pub availability_zone: Option<String>,
    pub city: Option<String>,
    pub continent: Option<String>,
    pub creation_timestamp: Option<String>,
    pub description: Option<String>,
    pub facility_provider: Option<String>,
    pub facility_provider_facility_id: Option<String>,
    pub id: Option<String>,
    pub kind: Option<String>,
    pub name: Option<String>,
    pub peeringdb_facility_id: Option<String>,
    pub region_infos: Option<Vec<InterconnectLocationRegionInfo>>,
    pub self_link: Option<String>,
    pub status: Option<String>,
}

Represents an Interconnect Attachment (VLAN) Location resource.

You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

address: Option<String>

[Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character.

availability_zone: Option<String>

[Output Only] Availability zone for this InterconnectLocation. Within a metropolitan area (metro), maintenance will not be simultaneously scheduled in more than one availability zone. Example: “zone1” or “zone2”.

city: Option<String>

[Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: “Chicago, IL”, “Amsterdam, Netherlands”.

continent: Option<String>

[Output Only] Continent for this location, which can take one of the following values:

  • AFRICA
  • ASIA_PAC
  • EUROPE
  • NORTH_AMERICA
  • SOUTH_AMERICA
creation_timestamp: Option<String>

[Output Only] Creation timestamp in RFC3339 text format.

description: Option<String>

[Output Only] An optional description of the resource.

facility_provider: Option<String>

[Output Only] The name of the provider for this facility (e.g., EQUINIX).

facility_provider_facility_id: Option<String>

[Output Only] A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).

id: Option<String>

[Output Only] The unique identifier for the resource. This identifier is defined by the server.

kind: Option<String>

[Output Only] Type of the resource. Always compute#interconnectLocation for interconnect locations.

name: Option<String>

[Output Only] Name of the resource.

peeringdb_facility_id: Option<String>

[Output Only] The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).

region_infos: Option<Vec<InterconnectLocationRegionInfo>>

[Output Only] A list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions.

self_link: Option<String>

[Output Only] Server-defined URL for the resource.

status: Option<String>

[Output Only] The status of this InterconnectLocation, which can take one of the following values:

  • CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects.
  • AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects.