pub struct InterconnectsGetDiagnosticsResponse {
pub result: Option<InterconnectDiagnostics>,
}Expand description
Response for the InterconnectsGetDiagnosticsRequest.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get diagnostics interconnects (response)
Fields
result: Option<InterconnectDiagnostics>no description provided