Struct google_compute1::api::NetworkEndpoint[][src]

pub struct NetworkEndpoint {
    pub annotations: Option<HashMap<String, String>>,
    pub fqdn: Option<String>,
    pub instance: Option<String>,
    pub ip_address: Option<String>,
    pub port: Option<i32>,
}

The network endpoint.

This type is not used in any activity, and only used as part of another schema.

Fields

annotations: Option<HashMap<String, String>>

Metadata defined as annotations on the network endpoint.

fqdn: Option<String>

Optional fully qualified domain name of network endpoint. This can only be specified when NetworkEndpointGroup.network_endpoint_type is NON_GCP_FQDN_PORT.

instance: Option<String>

The name for a specific VM instance that the IP address belongs to. This is required for network endpoints of type GCE_VM_IP_PORT. The instance must be in the same zone of network endpoint group.

The name must be 1-63 characters long, and comply with RFC1035.

ip_address: Option<String>

Optional IPv4 address of network endpoint. The IP address must belong to a VM in Compute Engine (either the primary IP or as part of an aliased IP range). If the IP address is not specified, then the primary IP address for the VM instance in the network that the network endpoint group belongs to will be used.

port: Option<i32>

Optional port number of network endpoint. If not specified, the defaultPort for the network endpoint group will be used.