Struct google_compute1::api::PublicAdvertisedPrefix[][src]

pub struct PublicAdvertisedPrefix {
    pub creation_timestamp: Option<String>,
    pub description: Option<String>,
    pub dns_verification_ip: Option<String>,
    pub fingerprint: Option<String>,
    pub id: Option<String>,
    pub ip_cidr_range: Option<String>,
    pub kind: Option<String>,
    pub name: Option<String>,
    pub public_delegated_prefixs: Option<Vec<PublicAdvertisedPrefixPublicDelegatedPrefix>>,
    pub self_link: Option<String>,
    pub shared_secret: Option<String>,
    pub status: Option<String>,
}

A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

creation_timestamp: Option<String>

[Output Only] Creation timestamp in RFC3339 text format.

description: Option<String>

An optional description of this resource. Provide this property when you create the resource.

dns_verification_ip: Option<String>

The IPv4 address to be used for reverse DNS verification.

fingerprint: Option<String>

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-date fingerprint must be provided in order to update the PublicAdvertisedPrefix, otherwise the request will fail with error 412 conditionNotMet.

To see the latest fingerprint, make a get() request to retrieve a PublicAdvertisedPrefix.

id: Option<String>

[Output Only] The unique identifier for the resource type. The server generates this identifier.

ip_cidr_range: Option<String>

The IPv4 address range, in CIDR format, represented by this public advertised prefix.

kind: Option<String>

[Output Only] Type of the resource. Always compute#publicAdvertisedPrefix for public advertised prefixes.

name: Option<String>

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

public_delegated_prefixs: Option<Vec<PublicAdvertisedPrefixPublicDelegatedPrefix>>

[Output Only] The list of public delegated prefixes that exist for this public advertised prefix.

self_link: Option<String>

[Output Only] Server-defined URL for the resource.

shared_secret: Option<String>

[Output Only] The shared secret to be used for reverse DNS verification.

status: Option<String>

The status of the public advertised prefix.