pub struct PublicAdvertisedPrefixList {
pub id: Option<String>,
pub items: Option<Vec<PublicAdvertisedPrefix>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<PublicAdvertisedPrefixListWarning>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list public advertised prefixes (response)
Fields
id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
items: Option<Vec<PublicAdvertisedPrefix>>A list of PublicAdvertisedPrefix resources.
kind: Option<String>[Output Only] Type of the resource. Always compute#publicAdvertisedPrefix for public advertised prefixes.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>[Output Only] Server-defined URL for this resource.
warning: Option<PublicAdvertisedPrefixListWarning>[Output Only] Informational warning message.