Struct google_compute1::api::RegionDisksRemoveResourcePoliciesRequest[][src]

pub struct RegionDisksRemoveResourcePoliciesRequest {
    pub resource_policies: Option<Vec<String>>,
}

There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

resource_policies: Option<Vec<String>>

Resource policies to be removed from this disk.