Struct google_compute1::api::ReservationList [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list reservations (response)
Fields
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
items: Option<Vec<Reservation>>[Output Only] A list of Allocation resources.
kind: Option<String>[Output Only] Type of resource.Always compute#reservationsList for listsof reservations
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
self_link: Option<String>[Output Only] Server-defined URL for this resource.
warning: Option<ReservationListWarning>[Output Only] Informational warning message.