Struct google_compute1::api::ResourcePolicySnapshotSchedulePolicy[][src]

pub struct ResourcePolicySnapshotSchedulePolicy {
    pub retention_policy: Option<ResourcePolicySnapshotSchedulePolicyRetentionPolicy>,
    pub schedule: Option<ResourcePolicySnapshotSchedulePolicySchedule>,
    pub snapshot_properties: Option<ResourcePolicySnapshotSchedulePolicySnapshotProperties>,
}

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.

This type is not used in any activity, and only used as part of another schema.

Fields

retention_policy: Option<ResourcePolicySnapshotSchedulePolicyRetentionPolicy>

Retention policy applied to snapshots created by this resource policy.

schedule: Option<ResourcePolicySnapshotSchedulePolicySchedule>

A Vm Maintenance Policy specifies what kind of infrastructure maintenance we are allowed to perform on this VM and when. Schedule that is applied to disks covered by this policy.

snapshot_properties: Option<ResourcePolicySnapshotSchedulePolicySnapshotProperties>

Properties with which snapshots are created such as labels, encryption keys.