Struct google_compute1::api::ScalingScheduleStatus[][src]

pub struct ScalingScheduleStatus {
    pub last_start_time: Option<String>,
    pub next_start_time: Option<String>,
    pub state: Option<String>,
}

There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

last_start_time: Option<String>

[Output Only] The last time the scaling schedule became active. Note: this is a timestamp when a schedule actually became active, not when it was planned to do so. The timestamp is in RFC3339 text format.

next_start_time: Option<String>

[Output Only] The next time the scaling schedule is to become active. Note: this is a timestamp when a schedule is planned to run, but the actual time might be slightly different. The timestamp is in RFC3339 text format.

state: Option<String>

[Output Only] The current state of a scaling schedule.