pub struct ServiceAttachmentAggregatedListWarning {
pub code: Option<String>,
pub data: Option<Vec<ServiceAttachmentAggregatedListWarningData>>,
pub message: Option<String>,
}Expand description
[Output Only] Informational warning message.
This type is not used in any activity, and only used as part of another schema.
Fields
code: Option<String>[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response.
data: Option<Vec<ServiceAttachmentAggregatedListWarningData>>[Output Only] Metadata about this warning in key: value format. For example: “data”: [ { “key”: “scope”, “value”: “zones/us-east1-d” }
message: Option<String>[Output Only] A human-readable description of the warning code.