Struct google_compute1::api::TargetHttpProxy [−][src]
Represents a Target HTTP Proxy resource.
Google Compute Engine has two Target HTTP Proxy resources:
A target HTTP proxy is a component of GCP HTTP load balancers.
- targetHttpProxies are used by external HTTP load balancers and Traffic Director. * regionTargetHttpProxies are used by internal HTTP load balancers.
Forwarding rules reference a target HTTP proxy, and the target proxy then references a URL map. For more information, read Using Target Proxies and Forwarding rule concepts. (== resource_for {$api_version}.targetHttpProxies ==) (== resource_for {$api_version}.regionTargetHttpProxies ==)
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get region target http proxies (response)
- insert region target http proxies (request)
- get target http proxies (response)
- insert target http proxies (request)
- patch target http proxies (request)
Fields
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
fingerprint: Option<String>Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetHttpProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetHttpProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetHttpProxy.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>[Output Only] Type of resource. Always compute#targetHttpProxy for target HTTP proxies.
name: Option<String>Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
proxy_bind: Option<bool>This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set to INTERNAL_SELF_MANAGED.
When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them.
The default is false.
region: Option<String>[Output Only] URL of the region where the regional Target HTTP Proxy resides. This field is not applicable to global Target HTTP Proxies.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
url_map: Option<String>URL to the UrlMap resource that defines the mapping from URL to the BackendService.