pub struct TargetHttpsProxiesScopedList {
pub target_https_proxies: Option<Vec<TargetHttpsProxy>>,
pub warning: Option<TargetHttpsProxiesScopedListWarning>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
target_https_proxies: Option<Vec<TargetHttpsProxy>>A list of TargetHttpsProxies contained in this scope.
warning: Option<TargetHttpsProxiesScopedListWarning>Informational warning which replaces the list of backend services when the list is empty.