Struct google_compute1::api::UrlMapsValidateRequest[][src]

pub struct UrlMapsValidateRequest {
    pub resource: Option<UrlMap>,
}

There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

resource: Option<UrlMap>

Content of the UrlMap to be validated.