Struct google_compute1::api::UrlMapsValidateResponse [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- validate region url maps (response)
- validate url maps (response)
Fields
result: Option<UrlMapValidationResult>no description provided