pub struct UsableSubnetworksAggregatedList {
pub id: Option<String>,
pub items: Option<Vec<UsableSubnetwork>>,
pub kind: Option<String>,
pub next_page_token: Option<String>,
pub self_link: Option<String>,
pub warning: Option<UsableSubnetworksAggregatedListWarning>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list usable subnetworks (response)
Fields
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
items: Option<Vec<UsableSubnetwork>>[Output] A list of usable subnetwork URLs.
kind: Option<String>[Output Only] Type of resource. Always compute#usableSubnetworksAggregatedList for aggregated lists of usable subnetworks.
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks and nextPageToken which still should be used to get the next page of results.
self_link: Option<String>[Output Only] Server-defined URL for this resource.
warning: Option<UsableSubnetworksAggregatedListWarning>[Output Only] Informational warning message.