Struct google_compute1::AccessConfig
source · pub struct AccessConfig {
pub kind: Option<String>,
pub type_: Option<String>,
pub name: Option<String>,
pub nat_ip: Option<String>,
}Expand description
An access configuration attached to an instance’s network interface. Only one access config per instance is supported.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- add access config instances (request)
Fields
kind: Option<String>[Output Only] Type of the resource. Always compute#accessConfig for access configs.
type_: Option<String>The type of configuration. The default and only option is ONE_TO_ONE_NAT.
name: Option<String>The name of this access configuration. The default and recommended name is External NAT but you can use any arbitrary string you would like. For example, My external IP or Network Access.
nat_ip: Option<String>An external IP address associated with this instance. Specify an unused static external IP address available to the project or leave this field undefined to use an IP from a shared ephemeral IP address pool. If you specify a static external IP address, it must live in the same region as the zone of the instance.