Struct google_compute1::AliasIpRange
source · pub struct AliasIpRange {
pub subnetwork_range_name: Option<String>,
pub ip_cidr_range: Option<String>,
}Expand description
An alias IP range attached to an instance’s network interface.
This type is not used in any activity, and only used as part of another schema.
Fields
subnetwork_range_name: Option<String>Optional subnetwork secondary range name specifying the secondary range from which to allocate the IP CIDR range for this alias IP range. If left unspecified, the primary range of the subnetwork will be used.
ip_cidr_range: Option<String>The IP CIDR range represented by this alias IP range. This IP CIDR range must belong to the specified subnetwork and cannot contain IP addresses reserved by system or used by other network interfaces. This range may be a single IP address (e.g. 10.2.3.4), a netmask (e.g. /24) or a CIDR format string (e.g. 10.1.2.0/24).