Struct google_compute1::DiskMoveRequest
source · pub struct DiskMoveRequest {
pub target_disk: Option<String>,
pub destination_zone: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- move disk projects (request)
Fields
target_disk: Option<String>The URL of the target disk to move. This can be a full or partial URL. For example, the following are all valid URLs to a disk:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk
destination_zone: Option<String>The URL of the destination zone to move the disk. This can be a full or partial URL. For example, the following are all valid URLs to a zone:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone