Struct google_compute1::GlobalSetLabelsRequest

source ·
pub struct GlobalSetLabelsRequest {
    pub label_fingerprint: Option<String>,
    pub labels: Option<HashMap<String, String>>,
}
There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

label_fingerprint: Option<String>

The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash when updating or changing labels. Make a get() request to the resource to get the latest fingerprint.

labels: Option<HashMap<String, String>>

A list of labels to apply for this resource. Each label key & value must comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. For example, “webserver-frontend”: “images”. A label value can also be empty (e.g. “my-label”: “”).