Struct google_compute1::InstanceMoveRequest
source · pub struct InstanceMoveRequest {
pub target_instance: Option<String>,
pub destination_zone: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- move instance projects (request)
Fields
target_instance: Option<String>The URL of the target instance to move. This can be a full or partial URL. For example, the following are all valid URLs to an instance:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
- projects/project/zones/zone/instances/instance
- zones/zone/instances/instance
destination_zone: Option<String>The URL of the destination zone to move the instance. This can be a full or partial URL. For example, the following are all valid URLs to a zone:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone