Struct google_compute1::MachineType
source · pub struct MachineType {Show 15 fields
pub guest_cpus: Option<i32>,
pub image_space_gb: Option<i32>,
pub kind: Option<String>,
pub description: Option<String>,
pub zone: Option<String>,
pub maximum_persistent_disks_size_gb: Option<String>,
pub deprecated: Option<DeprecationStatus>,
pub maximum_persistent_disks: Option<i32>,
pub memory_mb: Option<i32>,
pub is_shared_cpu: Option<bool>,
pub scratch_disks: Option<Vec<MachineTypeScratchDisks>>,
pub creation_timestamp: Option<String>,
pub id: Option<String>,
pub self_link: Option<String>,
pub name: Option<String>,
}Expand description
A Machine Type resource. (== resource_for v1.machineTypes ==) (== resource_for beta.machineTypes ==)
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list machine types (none)
- aggregated list machine types (none)
- get machine types (response)
Fields
guest_cpus: Option<i32>[Output Only] The number of virtual CPUs that are available to the instance.
image_space_gb: Option<i32>[Deprecated] This property is deprecated and will never be populated with any relevant values.
kind: Option<String>[Output Only] The type of the resource. Always compute#machineType for machine types.
description: Option<String>[Output Only] An optional textual description of the resource.
zone: Option<String>[Output Only] The name of the zone where the machine type resides, such as us-central1-a.
maximum_persistent_disks_size_gb: Option<String>[Output Only] Maximum total persistent disks size (GB) allowed.
deprecated: Option<DeprecationStatus>[Output Only] The deprecation status associated with this machine type.
maximum_persistent_disks: Option<i32>[Output Only] Maximum persistent disks allowed.
memory_mb: Option<i32>[Output Only] The amount of physical memory available to the instance, defined in MB.
[Output Only] Whether this machine type has a shared CPU. See Shared-core machine types for more information.
scratch_disks: Option<Vec<MachineTypeScratchDisks>>[Output Only] A list of extended scratch disks assigned to the instance.
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
name: Option<String>[Output Only] Name of the resource.