Struct google_compute1::NetworkInterface

source ·
pub struct NetworkInterface {
    pub kind: Option<String>,
    pub alias_ip_ranges: Option<Vec<AliasIpRange>>,
    pub network: Option<String>,
    pub access_configs: Option<Vec<AccessConfig>>,
    pub network_ip: Option<String>,
    pub fingerprint: Option<String>,
    pub subnetwork: Option<String>,
    pub name: Option<String>,
}
A network interface resource attached to an instance.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

kind: Option<String>

[Output Only] Type of the resource. Always compute#networkInterface for network interfaces.

alias_ip_ranges: Option<Vec<AliasIpRange>>

An array of alias IP ranges for this network interface. Can only be specified for network interfaces on subnet-mode networks.

network: Option<String>

URL of the network resource for this instance. When creating an instance, if neither the network nor the subnetwork is specified, the default network global/networks/default is used; if the network is not specified but the subnetwork is specified, the network is inferred.

This field is optional when creating a firewall rule. If not specified when creating a firewall rule, the default network global/networks/default is used.

If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs:

  • https://www.googleapis.com/compute/v1/projects/project/global/networks/network
  • projects/project/global/networks/network
  • global/networks/default
access_configs: Option<Vec<AccessConfig>>

An array of configurations for this interface. Currently, only one access config, ONE_TO_ONE_NAT, is supported. If there are no accessConfigs specified, then this instance will have no external internet access.

network_ip: Option<String>

An IPv4 internal network address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system.

fingerprint: Option<String>

Fingerprint hash of contents stored in this network interface. This field will be ignored when inserting an Instance or adding a NetworkInterface. An up-to-date fingerprint must be provided in order to update the NetworkInterface.

subnetwork: Option<String>

The URL of the Subnetwork resource for this instance. If the network resource is in legacy mode, do not provide this property. If the network is in auto subnet mode, providing the subnetwork is optional. If the network is in custom subnet mode, then this field should be specified. If you specify this property, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:

  • https://www.googleapis.com/compute/v1/projects/project/regions/region/subnetworks/subnetwork
  • regions/region/subnetworks/subnetwork
name: Option<String>

[Output Only] The name of the network interface, generated by the server. For network devices, these are eth0, eth1, etc.