Struct google_compute1::Project

source ·
pub struct Project {
Show 13 fields pub kind: Option<String>, pub default_service_account: Option<String>, pub description: Option<String>, pub common_instance_metadata: Option<Metadata>, pub quotas: Option<Vec<Quota>>, pub usage_export_location: Option<UsageExportLocation>, pub enabled_features: Option<Vec<String>>, pub xpn_project_status: Option<String>, pub default_network_tier: Option<String>, pub creation_timestamp: Option<String>, pub id: Option<String>, pub self_link: Option<String>, pub name: Option<String>,
}
A Project resource. For an overview of projects, see Cloud Platform Resource Hierarchy. (== resource_for v1.projects ==) (== resource_for beta.projects ==)

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

kind: Option<String>

[Output Only] Type of the resource. Always compute#project for projects.

default_service_account: Option<String>

[Output Only] Default service account used by VMs running in this project.

description: Option<String>

An optional textual description of the resource.

common_instance_metadata: Option<Metadata>

Metadata key/value pairs available to all instances contained in this project. See Custom metadata for more information.

quotas: Option<Vec<Quota>>

[Output Only] Quotas assigned to this project.

usage_export_location: Option<UsageExportLocation>

The naming prefix for daily usage reports and the Google Cloud Storage bucket where they are stored.

enabled_features: Option<Vec<String>>

Restricted features enabled for use on this project.

xpn_project_status: Option<String>

[Output Only] The role this project has in a shared VPC configuration. Currently only HOST projects are differentiated.

default_network_tier: Option<String>

This signifies the default network tier used for configuring resources of the project and can only take the following values: PREMIUM, STANDARD. Initially the default network tier is PREMIUM.

creation_timestamp: Option<String>

[Output Only] Creation timestamp in RFC3339 text format.

id: Option<String>

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources.

self_link: Option<String>

[Output Only] Server-defined URL for the resource.

name: Option<String>

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine.