Struct google_compute1::RouterStatus
source · pub struct RouterStatus {
pub bgp_peer_status: Option<Vec<RouterStatusBgpPeerStatus>>,
pub best_routes_for_router: Option<Vec<Route>>,
pub network: Option<String>,
pub best_routes: Option<Vec<Route>>,
}Expand description
There is no detailed description.
This type is not used in any activity, and only used as part of another schema.
Fields
bgp_peer_status: Option<Vec<RouterStatusBgpPeerStatus>>no description provided
best_routes_for_router: Option<Vec<Route>>Best routes learned by this router.
network: Option<String>URI of the network to which this router belongs.
best_routes: Option<Vec<Route>>Best routes for this router’s network.