Struct google_compute1::Scheduling
source · pub struct Scheduling {
pub automatic_restart: Option<bool>,
pub node_affinities: Option<Vec<SchedulingNodeAffinity>>,
pub preemptible: Option<bool>,
pub on_host_maintenance: Option<String>,
}Expand description
Sets the scheduling options for an Instance.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- set scheduling instances (request)
Fields
automatic_restart: Option<bool>Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user). You can only set the automatic restart option for standard instances. Preemptible instances cannot be automatically restarted.
By default, this is set to true so an instance is automatically restarted if it is terminated by Compute Engine.
node_affinities: Option<Vec<SchedulingNodeAffinity>>A set of node affinity and anti-affinity.
preemptible: Option<bool>Defines whether the instance is preemptible. This can only be set during instance creation, it cannot be set or changed after the instance has been created.
on_host_maintenance: Option<String>Defines the maintenance behavior for this instance. For standard instances, the default behavior is MIGRATE. For preemptible instances, the default and only possible behavior is TERMINATE. For more information, see Setting Instance Scheduling Options.