Struct google_compute1::SecurityPolicyRule
source · pub struct SecurityPolicyRule {
pub priority: Option<i32>,
pub kind: Option<String>,
pub description: Option<String>,
pub action: Option<String>,
pub preview: Option<bool>,
pub match_: Option<SecurityPolicyRuleMatcher>,
}Expand description
Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get rule security policies (response)
- add rule security policies (request)
- patch rule security policies (request)
Fields
priority: Option<i32>An integer indicating the priority of a rule in the list. The priority must be a positive value between 0 and 2147483647. Rules are evaluated in the increasing order of priority.
kind: Option<String>[Output only] Type of the resource. Always compute#securityPolicyRule for security policy rules
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
action: Option<String>The Action to preform when the client connection triggers the rule. Can currently be either “allow” or “deny()” where valid values for status are 403, 404, and 502.
preview: Option<bool>If set to true, the specified action is not enforced.
match_: Option<SecurityPolicyRuleMatcher>A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding ?action? is enforced.