Struct google_compute1::SecurityPolicyRuleMatcher

source ·
pub struct SecurityPolicyRuleMatcher {
    pub config: Option<SecurityPolicyRuleMatcherConfig>,
    pub versioned_expr: Option<String>,
}
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.

This type is not used in any activity, and only used as part of another schema.

Fields

config: Option<SecurityPolicyRuleMatcherConfig>

The configuration options available when specifying versioned_expr. This field must be specified if versioned_expr is specified and cannot be specified if versioned_expr is not specified.

versioned_expr: Option<String>

Preconfigured versioned expression. If this field is specified, config must also be specified. Available preconfigured expressions along with their requirements are: SRC_IPS_V1 - must specify the corresponding src_ip_range field in config.