Struct google_compute1::SerialPortOutput

source ·
pub struct SerialPortOutput {
    pub start: Option<String>,
    pub kind: Option<String>,
    pub contents: Option<String>,
    pub self_link: Option<String>,
    pub next: Option<String>,
}
An instance’s serial console output.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

start: Option<String>

The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer, older output will be overwritten by newer content and the start values will be mismatched.

kind: Option<String>

[Output Only] Type of the resource. Always compute#serialPortOutput for serial port output.

contents: Option<String>

[Output Only] The contents of the console output.

self_link: Option<String>

[Output Only] Server-defined URL for this resource.

next: Option<String>

[Output Only] The position of the next byte of content from the serial console output. Use this value in the next request as the start parameter.