Struct google_compute1::TargetHttpProxy
source · pub struct TargetHttpProxy {
pub kind: Option<String>,
pub description: Option<String>,
pub url_map: Option<String>,
pub creation_timestamp: Option<String>,
pub id: Option<String>,
pub self_link: Option<String>,
pub name: Option<String>,
}Expand description
A TargetHttpProxy resource. This resource defines an HTTP proxy. (== resource_for beta.targetHttpProxies ==) (== resource_for v1.targetHttpProxies ==)
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get target http proxies (response)
- insert target http proxies (request)
Fields
kind: Option<String>[Output Only] Type of resource. Always compute#targetHttpProxy for target HTTP proxies.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
url_map: Option<String>URL to the UrlMap resource that defines the mapping from URL to the BackendService.
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
name: Option<String>Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.