Struct google_compute1::TargetInstance
source · pub struct TargetInstance {
pub nat_policy: Option<String>,
pub description: Option<String>,
pub zone: Option<String>,
pub kind: Option<String>,
pub instance: Option<String>,
pub creation_timestamp: Option<String>,
pub id: Option<String>,
pub self_link: Option<String>,
pub name: Option<String>,
}Expand description
A TargetInstance resource. This resource defines an endpoint instance that terminates traffic of certain protocols. (== resource_for beta.targetInstances ==) (== resource_for v1.targetInstances ==)
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- delete target instances (none)
- aggregated list target instances (none)
- get target instances (response)
- list target instances (none)
- insert target instances (request)
Fields
nat_policy: Option<String>NAT option controlling how IPs are NAT’ed to the instance. Currently only NO_NAT (default value) is supported.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
zone: Option<String>[Output Only] URL of the zone where the target instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
kind: Option<String>[Output Only] The type of the resource. Always compute#targetInstance for target instances.
instance: Option<String>A URL to the virtual machine instance that handles traffic for this target instance. When creating a target instance, you can provide the fully-qualified URL or a valid partial URL to the desired virtual machine. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/instance
- projects/project/zones/zone/instances/instance
- zones/zone/instances/instance
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
name: Option<String>Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.