Struct google_compute1::TargetInstanceList
source · pub struct TargetInstanceList {
pub next_page_token: Option<String>,
pub kind: Option<String>,
pub warning: Option<TargetInstanceListWarning>,
pub items: Option<Vec<TargetInstance>>,
pub id: Option<String>,
pub self_link: Option<String>,
}Expand description
Contains a list of TargetInstance resources.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list target instances (response)
Fields
next_page_token: Option<String>[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results.
kind: Option<String>Type of resource.
warning: Option<TargetInstanceListWarning>[Output Only] Informational warning message.
items: Option<Vec<TargetInstance>>A list of TargetInstance resources.
id: Option<String>[Output Only] Unique identifier for the resource; defined by the server.
self_link: Option<String>[Output Only] Server-defined URL for this resource.