pub struct TargetPoolInstanceHealth {
pub kind: Option<String>,
pub health_status: Option<Vec<HealthStatus>>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get health target pools (response)
Fields
kind: Option<String>[Output Only] Type of resource. Always compute#targetPoolInstanceHealth when checking the health of an instance.
health_status: Option<Vec<HealthStatus>>no description provided