Struct google_compute1::api::AutoscalingPolicyScaleInControl [−][src]
Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.
This type is not used in any activity, and only used as part of another schema.
Fields
max_scaled_in_replicas: Option<FixedOrPercent>Maximum allowed number (or %) of VMs that can be deducted from the peak recommendation during the window autoscaler looks at when computing recommendations. Possibly all these VMs can be deleted at once so user service needs to be prepared to lose that many VMs in one step.
time_window_sec: Option<i32>How far back autoscaling looks when computing recommendations to include directives regarding slower scale in, as described above.