Struct google_compute1::api::GlobalNetworkEndpointGroupsDetachEndpointsRequest [−][src]
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
network_endpoints: Option<Vec<NetworkEndpoint>>The list of network endpoints to be detached.