Struct google_compute1::api::HttpHealthCheck [−][src]
Represents a legacy HTTP Health Check resource.
Legacy health checks are required by network load balancers. For more information, read Health Check Concepts.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- delete http health checks (none)
- get http health checks (response)
- insert http health checks (request)
- list http health checks (none)
- patch http health checks (request)
- update http health checks (request)
Fields
check_interval_sec: Option<i32>How often (in seconds) to send a health check. The default value is 5 seconds.
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
healthy_threshold: Option<i32>A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.
host: Option<String>The value of the host header in the HTTP health check request. If left empty (default value), the public IP on behalf of which this health check is performed will be used.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>[Output Only] Type of the resource. Always compute#httpHealthCheck for HTTP health checks.
name: Option<String>Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
port: Option<i32>The TCP port number for the HTTP health check request. The default value is 80.
request_path: Option<String>The request path of the HTTP health check request. The default value is /. This field does not support query parameters.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
timeout_sec: Option<i32>How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.
unhealthy_threshold: Option<i32>A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.