Struct google_compute1::api::MachineType [−][src]
Represents a Machine Type resource.
You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, read Machine Types. (== resource_for {$api_version}.machineTypes ==)
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- aggregated list machine types (none)
- get machine types (response)
- list machine types (none)
Fields
accelerators: Option<Vec<MachineTypeAccelerators>>[Output Only] A list of accelerator configurations assigned to this machine type.
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
deprecated: Option<DeprecationStatus>[Output Only] The deprecation status associated with this machine type. Only applicable if the machine type is unavailable.
description: Option<String>[Output Only] An optional textual description of the resource.
guest_cpus: Option<i32>[Output Only] The number of virtual CPUs that are available to the instance.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
image_space_gb: Option<i32>[Deprecated] This property is deprecated and will never be populated with any relevant values.
[Output Only] Whether this machine type has a shared CPU. See Shared-core machine types for more information.
kind: Option<String>[Output Only] The type of the resource. Always compute#machineType for machine types.
maximum_persistent_disks: Option<i32>[Output Only] Maximum persistent disks allowed.
maximum_persistent_disks_size_gb: Option<String>[Output Only] Maximum total persistent disks size (GB) allowed.
memory_mb: Option<i32>[Output Only] The amount of physical memory available to the instance, defined in MB.
name: Option<String>[Output Only] Name of the resource.
scratch_disks: Option<Vec<MachineTypeScratchDisks>>[Output Only] A list of extended scratch disks assigned to the instance.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
zone: Option<String>[Output Only] The name of the zone where the machine type resides, such as us-central1-a.