Struct google_compute1::api::Route [−][src]
Represents a Route resource.
A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read the Routes overview. (== resource_for {$api_version}.routes ==)
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- delete routes (none)
- get routes (response)
- insert routes (request)
- list routes (none)
Fields
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
description: Option<String>An optional description of this resource. Provide this field when you create the resource.
dest_range: Option<String>The destination range of outgoing packets that this route applies to. Both IPv4 and IPv6 are supported.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
kind: Option<String>[Output Only] Type of this resource. Always compute#routes for Route resources.
name: Option<String>Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit.
network: Option<String>Fully-qualified URL of the network that this route applies to.
next_hop_gateway: Option<String>The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects/project/global/gateways/default-internet-gateway
next_hop_ilb: Option<String>The URL to a forwarding rule of type loadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs:
- 10.128.0.56
- https://www.googleapis.com/compute/v1/projects/project/regions/region/forwardingRules/forwardingRule
- regions/region/forwardingRules/forwardingRule
next_hop_instance: Option<String>The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/
next_hop_ip: Option<String>The network IP address of an instance that should handle matching packets. Only IPv4 is supported.
next_hop_network: Option<String>The URL of the local network if it should handle matching packets.
next_hop_peering: Option<String>[Output Only] The network peering name that should handle matching packets, which should conform to RFC1035.
next_hop_vpn_tunnel: Option<String>The URL to a VpnTunnel that should handle matching packets.
priority: Option<u32>The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In cases where multiple routes have equal prefix length, the one with the lowest-numbered priority value wins. The default value is 1000. The priority value must be from 0 to 65535, inclusive.
self_link: Option<String>[Output Only] Server-defined fully-qualified URL for this resource.
A list of instance tags to which this route applies.
warnings: Option<Vec<RouteWarnings>>[Output Only] If potential misconfigurations are detected for this route, this field will be populated with warning messages.