Struct google_compute1::api::Router [−][src]
Represents a Cloud Router resource.
For more information about Cloud Router, read the Cloud Router overview.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- aggregated list routers (none)
- delete routers (none)
- get routers (response)
- get nat mapping info routers (none)
- get router status routers (none)
- insert routers (request)
- list routers (none)
- patch routers (request)
- preview routers (request)
- update routers (request)
Fields
bgp: Option<RouterBgp>BGP information specific to this router.
bgp_peers: Option<Vec<RouterBgpPeer>>BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer to RFC4273.
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
encrypted_interconnect_router: Option<bool>Field to indicate if a router is dedicated to use with encrypted Interconnect Attachment (IPsec-encrypted Cloud Interconnect feature). Not currently available in all Interconnect locations.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
interfaces: Option<Vec<RouterInterface>>Router interfaces. Each interface requires either one linked resource, (for example, linkedVpnTunnel), or IP address and IP address range (for example, ipRange), or both.
kind: Option<String>[Output Only] Type of resource. Always compute#router for routers.
name: Option<String>Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
nats: Option<Vec<RouterNat>>A list of NAT services created in this router.
network: Option<String>URI of the network to which this router belongs.
region: Option<String>[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
self_link: Option<String>[Output Only] Server-defined URL for the resource.