pub struct VmEndpointNatMappingsInterfaceNatMappings {
pub drain_nat_ip_port_ranges: Option<Vec<String>>,
pub nat_ip_port_ranges: Option<Vec<String>>,
pub num_total_drain_nat_ports: Option<i32>,
pub num_total_nat_ports: Option<i32>,
pub rule_mappings: Option<Vec<VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>>,
pub source_alias_ip_range: Option<String>,
pub source_virtual_ip: Option<String>,
}Expand description
Contain information of Nat mapping for an interface of this endpoint.
This type is not used in any activity, and only used as part of another schema.
Fields
drain_nat_ip_port_ranges: Option<Vec<String>>List of all drain IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: [“2.2.2.2:12345-12355”, “1.1.1.1:2234-2234”].
nat_ip_port_ranges: Option<Vec<String>>A list of all IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: [“2.2.2.2:12345-12355”, “1.1.1.1:2234-2234”].
num_total_drain_nat_ports: Option<i32>Total number of drain ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field drain_nat_ip_port_ranges.
num_total_nat_ports: Option<i32>Total number of ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field nat_ip_port_ranges.
rule_mappings: Option<Vec<VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>>Information about mappings provided by rules in this NAT.
source_alias_ip_range: Option<String>Alias IP range for this interface endpoint. It will be a private (RFC 1918) IP range. Examples: “10.33.4.55/32”, or “192.168.5.0/24”.
source_virtual_ip: Option<String>Primary IP of the VM for this NIC.