Struct google_compute1::AccessConfig

source ·
pub struct AccessConfig {
    pub network_tier: Option<String>,
    pub kind: Option<String>,
    pub name: Option<String>,
    pub nat_ip: Option<String>,
    pub set_public_ptr: Option<bool>,
    pub type_: Option<String>,
    pub public_ptr_domain_name: Option<String>,
}
An access configuration attached to an instance’s network interface. Only one access config per instance is supported.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

network_tier: Option<String>

This signifies the networking tier used for configuring this access configuration and can only take the following values: PREMIUM, STANDARD.

If an AccessConfig is specified without a valid external IP address, an ephemeral IP will be created with this networkTier.

If an AccessConfig with a valid external IP address is specified, it must match that of the networkTier associated with the Address resource owning that IP.

kind: Option<String>

[Output Only] Type of the resource. Always compute#accessConfig for access configs.

name: Option<String>

The name of this access configuration. The default and recommended name is External NAT but you can use any arbitrary string you would like. For example, My external IP or Network Access.

nat_ip: Option<String>

An external IP address associated with this instance. Specify an unused static external IP address available to the project or leave this field undefined to use an IP from a shared ephemeral IP address pool. If you specify a static external IP address, it must live in the same region as the zone of the instance.

set_public_ptr: Option<bool>

Specifies whether a public DNS ?PTR? record should be created to map the external IP address of the instance to a DNS domain name.

type_: Option<String>

The type of configuration. The default and only option is ONE_TO_ONE_NAT.

public_ptr_domain_name: Option<String>

The DNS domain name for the public PTR record. This field can only be set when the set_public_ptr field is enabled.