Struct google_compute1::LicenseCode
source · pub struct LicenseCode {
pub kind: Option<String>,
pub description: Option<String>,
pub transferable: Option<bool>,
pub state: Option<String>,
pub license_alias: Option<Vec<LicenseCodeLicenseAlias>>,
pub creation_timestamp: Option<String>,
pub id: Option<String>,
pub self_link: Option<String>,
pub name: Option<String>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get license codes (response)
- test iam permissions license codes (none)
Fields
kind: Option<String>[Output Only] Type of resource. Always compute#licenseCode for licenses.
description: Option<String>[Output Only] Description of this License Code.
transferable: Option<bool>[Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred.
state: Option<String>[Output Only] Current state of this License Code.
license_alias: Option<Vec<LicenseCodeLicenseAlias>>[Output Only] URL and description aliases of Licenses with the same License Code.
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
name: Option<String>[Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer.