Struct google_compute1::TargetPool
source · pub struct TargetPool {
pub failover_ratio: Option<f32>,
pub description: Option<String>,
pub region: Option<String>,
pub kind: Option<String>,
pub session_affinity: Option<String>,
pub instances: Option<Vec<String>>,
pub backup_pool: Option<String>,
pub health_checks: Option<Vec<String>>,
pub creation_timestamp: Option<String>,
pub id: Option<String>,
pub self_link: Option<String>,
pub name: Option<String>,
}Expand description
A TargetPool resource. This resource defines a pool of instances, an associated HttpHealthCheck resource, and the fallback target pool. (== resource_for beta.targetPools ==) (== resource_for v1.targetPools ==)
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get health target pools (none)
- add instance target pools (none)
- remove instance target pools (none)
- remove health check target pools (none)
- delete target pools (none)
- insert target pools (request)
- aggregated list target pools (none)
- list target pools (none)
- add health check target pools (none)
- get target pools (response)
- set backup target pools (none)
Fields
failover_ratio: Option<f32>This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool). The value of the field must be in [0, 1].
If set, backupPool must also be set. They together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below this number, traffic arriving at the load-balanced IP will be directed to the backup pool.
In case where failoverRatio is not set or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the “force” mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy.
description: Option<String>An optional description of this resource. Provide this property when you create the resource.
region: Option<String>[Output Only] URL of the region where the target pool resides.
kind: Option<String>[Output Only] Type of the resource. Always compute#targetPool for target pools.
session_affinity: Option<String>Sesssion affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool. CLIENT_IP: Connections from the same client IP will go to the same instance in the pool while that instance remains healthy. CLIENT_IP_PROTO: Connections from the same client IP with the same IP protocol will go to the same instance in the pool while that instance remains healthy.
instances: Option<Vec<String>>A list of resource URLs to the virtual machine instances serving this pool. They must live in zones contained in the same region as this pool.
backup_pool: Option<String>This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool, and its failoverRatio field is properly set to a value between [0, 1].
backupPool and failoverRatio together define the fallback behavior of the primary target pool: if the ratio of the healthy instances in the primary pool is at or below failoverRatio, traffic arriving at the load-balanced IP will be directed to the backup pool.
In case where failoverRatio and backupPool are not set, or all the instances in the backup pool are unhealthy, the traffic will be directed back to the primary pool in the “force” mode, where traffic will be spread to the healthy instances with the best effort, or to all instances when no instance is healthy.
health_checks: Option<Vec<String>>The URL of the HttpHealthCheck resource. A member instance in this pool is considered healthy if and only if the health checks pass. An empty list means all member instances will be considered healthy at all times. Only HttpHealthChecks are supported. Only one health check may be specified.
creation_timestamp: Option<String>[Output Only] Creation timestamp in RFC3339 text format.
id: Option<String>[Output Only] The unique identifier for the resource. This identifier is defined by the server.
self_link: Option<String>[Output Only] Server-defined URL for the resource.
name: Option<String>Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.